@@ -9,7 +9,7 @@ use constant {
     MINUTES_PER_HOUR => 60,
 };
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our $ERROR = '';
 our $BFLAG = 0;
 
@@ -99,46 +99,59 @@ Date::Remind::Event - Manipulate 'remind' output with Perl
 =head1 DESCRIPTION
 
 B<Date::Remind::Event> provides a Perl object interface to textual
-events emitted by L<remind>(1). The expected format of the input is the
-same as what is produced by "remind -s" (as defined in the L<rem2ps>(1)
-manpage under "REM2PS INPUT FORMAT").
+events emitted by the L<remind>(1) calendar program. The expected
+format of the input is the same as what is produced by "remind -s" (as
+defined in the L<rem2ps>(1) manpage under "REM2PS INPUT FORMAT").
 
 L<remind>(1) produces slightly different output depending on the value
-of the -b flag. To make sure that B<Date::Remind::Event> handles this
-correctly you should set B<$Date::Remind::Event::BFLAG> to the same
+of the -b flag. To make sure that Date::Remind::Event handles this
+correctly you should set $Date::Remind::Event::BFLAG to the same
 value (default is 0).
 
+See the "example/remind-simple" file in the distribution for one
+possible way of calling L<remind>(1) from within Perl and parsing its
+output.
+
 =head1 CONSTRUCTOR
 
-=head2 new($text) => Date::Remind::Event
+=over 4
+
+=item new($text) => Date::Remind::Event
 
 Converts $text into a single Date::Remind::Event object.
 
+=back
+
 =head1 ATTRIBUTES
 
-=head2 date => DateTime
+=over 4
+
+=item date -> DateTime
 
 The start of the event.
 
-=head2 duration => DateTime::Duration
+=item duration -> DateTime::Duration
 
 The length of the event.
 
-=head2 end => DateTime
+=item end -> DateTime
 
 The end of the remind event.
 
-=head2 tag => string
+=item tag -> string
 
 The TAG value of the event.
 
-=head2 body => string
+=item body -> string
 
 The body of the remind event.
 
+=back
+
 =head1 SEE ALSO
 
-L<DateTime>, L<DateTime::Duration>, L<remind>(1), L<rem2ps>(1)
+L<DateTime>, L<DateTime::Duration>, L<remind>(1), L<rem2ps>(1),
+http://www.roaringpenguin.com/products/remind
 
 =head1 AUTHOR
 
@@ -146,7 +159,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2010 Mark Lawrence <nomad@null.net>
+Copyright 2010-2011 Mark Lawrence
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
